pub enum FactorioExporterError {
FactorioExecutionError {
stdout: String,
stderr: String,
},
FactorioOutputError {
message: String,
output: String,
},
FileNotFoundError {
file: PathBuf,
},
InvocationError(String),
IoError(Error),
JsonParsingError(Error),
YamlParsingError(Error),
}Expand description
Main error type used throughout factorio-explorer
Variants
FactorioExecutionError
Error that is raised if Factorio could not be started to execute the exporter mods. The process output to stdout and stderr is saved in the error object.
FactorioOutputError
Error that is raised if Factorio’s output could not be parsed. This can have all kinds of root causes, but the underlying reason should normally be apparent from the process output stored in this error object.
FileNotFoundError
Fields
file: PathBufError that is raised if a file couldn’t be found, for example the API spec or the Factorio binary. This is usually a user error.
InvocationError(String)
Error that is raised if the user specified conflicting or incomplete command line arguments.
IoError(Error)
Error that is raised if a file system operation failed unexpectedly.
JsonParsingError(Error)
Error that is raised if deserialization from JSON failed.
YamlParsingError(Error)
Error that is raised if deserialization from JSON failed.